unit F_Main;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ImgList, Vcl.ExtCtrls,
  System.IniFiles;

type
  TfrmIISLogImporter = class(TForm)
    edtDatabase: TButtonedEdit;
    imlMain: TImageList;
    lblDatabase: TLabel;
    lblLogFolder: TLabel;
    edtLogFolder: TButtonedEdit;
    mmoLog: TMemo;
    btnExecute: TButton;
    dlgOpenDatabase: TFileOpenDialog;
    procedure edtDatabaseRightButtonClick(Sender: TObject);
    procedure edtLogFolderRightButtonClick(Sender: TObject);
    procedure btnExecuteClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure FormDestroy(Sender: TObject);
  private
    FSettings: TIniFile;
    procedure WriteSettings;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmIISLogImporter: TfrmIISLogImporter;

implementation
uses
  Vcl.FileCtrl,
  U_ILPController;

{$R *.dfm}

procedure TfrmIISLogImporter.FormCreate(Sender: TObject);
begin
  FSettings := TIniFile.Create(ChangeFileExt(ParamStr(0), '.ini'));
  edtDatabase.Text := FSettings.ReadString('Locations', 'Database', edtDatabase.Text);
  edtLogFolder.Text := FSettings.ReadString('Locations', 'Logs', edtLogFolder.Text);
end;

procedure TfrmIISLogImporter.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
begin
  WriteSettings;
end;

procedure TfrmIISLogImporter.FormDestroy(Sender: TObject);
begin
  FSettings.Free;
end;

procedure TfrmIISLogImporter.WriteSettings;
begin
  FSettings.WriteString('Locations', 'Database', edtDatabase.Text);
  FSettings.WriteString('Locations', 'Logs', edtLogFolder.Text);
end;

procedure TfrmIISLogImporter.edtDatabaseRightButtonClick(Sender: TObject);
begin
  if ExtractFileDir(edtDatabase.Text) <> '' then begin
    dlgOpenDatabase.DefaultFolder := ExtractFileDir(edtDatabase.Text);
    dlgOpenDatabase.FileName := ExtractFileName(edtDatabase.Text);
  end else begin
    dlgOpenDatabase.FileName := edtDatabase.Text;
  end;
  if dlgOpenDatabase.Execute then begin
    edtDatabase.Text := dlgOpenDatabase.FileName;
  end;
end;

procedure TfrmIISLogImporter.edtLogFolderRightButtonClick(Sender: TObject);
var
  LogFolder: string;
begin
  LogFolder := edtLogFolder.Text;
  if SelectDirectory('Select log folder', '', LogFolder, [sdNewFolder, sdShowEdit, sdNewUI], edtLogFolder) then begin
    edtLogFolder.Text := LogFolder;
  end;
end;

procedure TfrmIISLogImporter.btnExecuteClick(Sender: TObject);
begin
  Screen.Cursor := crHourGlass;
  btnExecute.Enabled := False;
  try
    WriteSettings;

    TILPController.Execute(edtDatabase.Text, edtLogFolder.Text,
                           procedure(const Text: string)
                           begin
                             mmoLog.SelStart := Length(mmoLog.Text);
                             mmoLog.SelText := Text.TrimRight + sLineBreak;
                             Application.ProcessMessages;
                           end);
  finally
    btnExecute.Enabled := True;
    Screen.Cursor := crDefault;
  end;
end;

end.
