program IISLogParser;

{$R *.dres}

uses
  Vcl.Forms,
  F_Main in 'F_Main.pas' {frmIISLogImporter},
  U_IISLogParser in 'U_IISLogParser.pas',
  System.SysUtils,
  System.Types,
  System.StrUtils,
  System.IOUtils,
  Winapi.Windows,
  SQLiteTable3,
  U_ILPController in 'U_ILPController.pas';

{$R *.res}

const
  ATTACH_PARENT_PROCESS: NativeUInt = High(NativeUInt);
var
  AttachConsole: function(dwProcessId: NativeUInt): LongBool; stdcall;
  ConsoleOutput: Boolean = False;

{ ---------------------------------------------------------------------------- }
procedure ShowMessage(const Text: string; const Error: boolean = False); overload;
var
  IconType: Cardinal;
begin
  if ConsoleOutput then begin
    if Error then
      WriteLn(ErrOutput, Text)
    else
      WriteLn(Text);
  end else begin
    if Error then
      IconType := MB_ICONERROR
    else
      IconType := MB_ICONINFORMATION;
    MessageBox(0, PChar(Text), PChar(ParamStr(0)), IconType);
  end;
end {ShowMessage};
{ ---------------------------------------------------------------------------- }
procedure ShowMessage(const Text: string; const Args: array of Const; const Error: boolean = False); overload;
begin
  ShowMessage(Format(Text, Args), Error);
end {ShowMessage};

{ ---------------------------------------------------------------------------- }
procedure ShowHelp;
resourcestring
  rsHelp = 'IISLogParser <database> <logfile | logfiles-folder>' + sLineBreak
         + '' + sLineBreak
         + 'database          The path and file name of the SQLite-database the ' + sLineBreak
         + '                  log files should be stored into. Will be created ' + sLineBreak
         + '                  if it doesn''t exist.' + sLineBreak
         + 'logfile           The log file to import.' + sLineBreak
         + 'logfiles-folder   Folder containing log files to import.' + sLineBreak;
begin
  ShowMessage(rsHelp);
end {ShowHelp};


////////////////////////////////////////////////////////////////////////////////
var
  DatabaseName, FileName: string;
begin
//  ReportMemoryLeaksOnShutdown := {$IFDEF DEBUG}True{$ELSE}False{$ENDIF};

  if ParamCount > 0 then begin
    AttachConsole := GetProcAddress(GetModuleHandle('kernel32.dll'), 'AttachConsole');
    ConsoleOutput := Assigned(AttachConsole) and AttachConsole(ATTACH_PARENT_PROCESS);
    if IndexText(ParamStr(1), ['/?', '/h', '/help', '-h', '-help', '--help']) > -1 then begin
      ShowHelp;
      Exit;
    end;

    try
      DatabaseName := ParamStr(1);
      FileName := ParamStr(2);
      TILPController.Execute(DatabaseName, FileName,
                              procedure(const Text: string)
                              begin
                                if ConsoleOutput then
                                  WriteLn(Text);
                              end);
    except
      on E: Exception do begin
        ShowMessage(E.Message, True);
      end;
    end;
  end else begin
    Application.Initialize;
    Application.MainFormOnTaskbar := True;
    Application.CreateForm(TfrmIISLogImporter, frmIISLogImporter);
    Application.Run;
  end;
end.
