CREATE TABLE Files
( id            INTEGER NOT NULL    PRIMARY KEY 
, path          TEXT
, filename      TEXT    NOT NULL    
, size          INTEGER NOT NULL
, last_modified TIMESTAMP           DEFAULT CURRENT_TIMESTAMP
, UNIQUE (path, filename)           ON CONFLICT REPLACE
);

CREATE TABLE Sections
( id            INTEGER NOT NULL    PRIMARY KEY
, file_id       INTEGER             REFERENCES Files(id)    ON DELETE CASCADE
, first_line    INTEGER NOT NULL
, software      TEXT
, version       TEXT
, datetime      TIMESTAMP
, fields        TEXT    UNIQUE      COLLATE NOCASE
, fieldset_id   INTEGER             REFERENCES Sections(id) ON DELETE RESTRICT
);

CREATE TABLE SectionValues
( id            INTEGER NOT NULL    PRIMARY KEY
, section_id    INTEGER NOT NULL    REFERENCES Sections(id) ON DELETE CASCADE
, line          INTEGER
, name          TEXT                COLLATE NOCASE
, value         TEXT
);

CREATE TABLE SectionFields
( id            INTEGER NOT NULL    PRIMARY KEY
, section_id    INTEGER NOT NULL    REFERENCES Sections(id) ON DELETE CASCADE
, ordinal       INTEGER NOT NULL
, name          TEXT    NOT NULL    COLLATE NOCASE
);

CREATE INDEX SectionFields_Section ON SectionFields(section_id);

CREATE TABLE Entries
( id                INTEGER NOT NULL    PRIMARY KEY
, file_id           INTEGER NOT NULL    REFERENCES Files(id)    ON DELETE CASCADE
, line              INTEGER NOT NULL
, section_id        INTEGER             REFERENCES Sections(id) ON DELETE CASCADE
, datetime          TIMESTAMP
, method            TEXT
, host              TEXT
, port              INTEGER
, path              TEXT
, query             TEXT
, remote_ip         TEXT
, user_agent        TEXT
, referrer          TEXT
, status            INTEGER
, substatus         INTEGER
, os_status         INTEGER
, request_bytes     INTEGER
, response_bytes    INTEGER
, time_taken        INTEGER
);

CREATE TABLE EntryFields
( entry_id          INTEGER NOT NULL    REFERENCES Entries(id)           ON DELETE CASCADE
, ordinal           INTEGER NOT NULL
, section_field_id  INTEGER             REFERENCES SectionFields(id)     ON DELETE CASCADE
, value             TEXT
);

CREATE TABLE EntryURIParameters
( entry_id      INTEGER NOT NULL    REFERENCES Entries(id)   ON DELETE CASCADE
, ordinal       INTEGER NOT NULL
, name          TEXT    NOT NULL    COLLATE NOCASE
, value         TEXT
);

CREATE TABLE EntryASPErrors
( entry_id      INTEGER NOT NULL    REFERENCES Entries(id)   ON DELETE CASCADE
, source_line   INTEGER
, error_code    TEXT
, message       TEXT
);

CREATE TABLE EntryCookies
( entry_id      INTEGER NOT NULL    REFERENCES Entries(id)   ON DELETE CASCADE
, ordinal       INTEGER NOT NULL
, name          TEXT    NOT NULL    COLLATE NOCASE
, value         TEXT
);

