unit U_ILPController;

interface
uses
  U_IISLogParser;

type
  TILPController = class
  type
    TLogDelegate = reference to procedure(const Text: string);
  public
    class function Execute(const DatabaseName, LogPath: string;
                           const WriteLog: TLogDelegate): Cardinal;
  end;

implementation
uses
  System.SysUtils, System.IOUtils, System.Types,
  SQLiteTable3;

{ TILPController }

class function TILPController.Execute(const DatabaseName, LogPath: string;
                                      const WriteLog: TLogDelegate): Cardinal;
var
  LogFile: string;
  EntryCount: Cardinal;
begin
  Result := 0;

  with U_IISLogParser.TIISLogParser.Create(':memory:') do
  try
    WriteLog('Initializing database ' + DatabaseName);
    DB.RestoreFrom(DatabaseName);
    InitTables;

    if TDirectory.Exists(LogPath) then begin
      WriteLog(LogPath + '...');
      for LogFile in TDirectory.GetFiles(LogPath, '*.log') do begin
        WriteLog(ExtractFileName(LogFile));
        EntryCount := ParseLogFile(LogFile);
        Inc(Result, EntryCount);
        if EntryCount > 0 then
          WriteLog(IntToStr(EntryCount) + ' entries');
      end;
    end else begin
      WriteLog(LogPath);
      EntryCount := ParseLogFile(LogFile);
      Inc(Result, EntryCount);
    end;

    WriteLog(IntToStr(Result) + ' log entries imported from ' + LogPath);
    WriteLog('Saving imported changes in ' + DatabaseName);
    DB.BackupTo(DatabaseName);
  finally
    Free;
  end;
end;

end.
